Index: wp-content/themes/twentytwelve/style.css
===================================================================
--- wp-content/themes/twentytwelve/style.css	(revision 21274)
+++ wp-content/themes/twentytwelve/style.css	(working copy)
@@ -435,7 +435,10 @@
 	}
 }
 @media screen and (min-width: 960px) {
-	body.custom-background #page {
+	body {
+		background-color: #e6e6e6;		
+	}
+	body #page {
 		padding: 0 40px;
 		padding: 0 2.857142857rem;
 		margin-top: 48px;
@@ -446,6 +449,16 @@
 		-moz-box-shadow: 0 2px 6px rgba(100, 100, 100, 0.3);
 		box-shadow: 0 2px 6px rgba(100, 100, 100, 0.3);
 	}
+	body.custom-background-empty {
+		background-color: #fff;
+	}
+	body.custom-background-empty #page,
+	body.custom-background-white #page {
+		padding: 0;
+		margin-top: 0;
+		margin-bottom: 0;
+		box-shadow: none;
+	}
 }
 #main {
 	zoom: 1;

Index: wp-content/themes/twentytwelve/functions.php
===================================================================
--- wp-content/themes/twentytwelve/functions.php	(revision 21274)
+++ wp-content/themes/twentytwelve/functions.php	(working copy)
@@ -71,7 +71,9 @@
 	register_nav_menu( 'primary', __( 'Primary Menu', 'twentytwelve' ) );
 
 	// Add support for custom background.
-	add_theme_support( 'custom-background' );
+	add_theme_support( 'custom-background', array(
+		'default-color' => 'e6e6e6',
+	) );
 
 	// Add custom image size for featured image use, displayed on "standard" posts.
 	add_theme_support( 'post-thumbnails' );
@@ -302,14 +304,22 @@
 /**
  * Extends the default WordPress body class to denote a full-width layout.
  *
  * Used in two cases: no active widgets in sidebar, and full-width page template.
  *
  * @since Twenty Twelve 1.0
  */
 function twentytwelve_body_class( $classes ) {
+	$background_color = get_background_color();
+
 	if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'full-width' ) )
 		$classes[] = 'full-width';
 
+	if ( empty( $background_color ) )
+		$classes[] = 'custom-background-empty';
+	elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )
+		$classes[] = 'custom-background-white';
+
 	return $classes;
 }
 add_filter( 'body_class', 'twentytwelve_body_class' );
@@ -302,14 +304,22 @@
  * Extends the default WordPress body class to denote a full-width layout.
  *
- * Used in two cases: no active widgets in sidebar, and full-width page template.
+ * 'full-width' used for no active widgets in sidebar, and full-width page template.
+ * 'white-background' used for white custom background color.
  *
  * @since Twenty Twelve 1.0